@@ -19,8 +19,8 @@
  * 
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 021110-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301 USA.
  *
  */
 
@@ -1194,7 +1194,7 @@ static void do_logdump(char **args)
 	uint16_t slotnum;
 	uint64_t blkno;
 	FILE *out;
-	int index = 1, traverse = 1;
+	int index = 1;
 	const char *logdump_usage = "usage: logdump [-T] <slot#>";
 
 	if (check_device_open())
@@ -1206,7 +1206,6 @@ static void do_logdump(char **args)
 	}
 
 	if (!strncmp(args[index], "-T", 2)) {
-		traverse = 0;
 		index++;
 	}
 
