@@ -15,8 +15,8 @@
  * 
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 021110-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301 USA.
  *
  * --
  *
@@ -177,7 +177,7 @@ static void check_discontig_bg(o2fsck_state *ost, int cpg,
 	if ((bg->bg_list.l_count >
 	     ocfs2_extent_recs_per_gd(ost->ost_fs->fs_blocksize)) &&
 	    prompt(ost, PY, PR_DISCONTIG_BG_COUNT,
-		   "Discontigous group descriptor at block %"PRIu64" has "
+		   "Discontiguous group descriptor at block %"PRIu64" has "
 		   "an extent count of %u, but discontiguous groups can "
 		   "only hold %u records.  Set it to %u?", blkno,
 		   bg->bg_list.l_count,
@@ -565,7 +565,7 @@ static void unlink_group_desc(o2fsck_state *ost,
 	ret = ocfs2_write_inode(ost->ost_fs, di->i_blkno, (char *)di);
 	if (ret) {
 		/* XXX ugh, undo the bitmap math? */
-		com_err(whoami, ret, "while writing inode alloc inode "
+		com_err(whoami, ret, "while writing global bitmap inode "
 			    "%"PRIu64, (uint64_t)di->i_blkno);
 		ost->ost_saw_error = 1;
 		goto out;
@@ -635,7 +635,15 @@ static errcode_t maybe_fix_clusters_per_group(o2fsck_state *ost,
 	blkno = cl->cl_recs[0].c_blkno;
 
 	ret = ocfs2_read_group_desc(ost->ost_fs, blkno, (char *)gd);
-	if (ret) {
+	if ((ret == OCFS2_ET_BAD_GROUP_DESC_MAGIC) ||
+	    (!ret && gd->bg_generation != ost->ost_fs_generation)) {
+		if (prompt(ost, PY, PR_GROUP_EXPECTED_DESC,
+			    "Group descriptor at block %"PRIu64" is corrupted. "
+			    "Go fixing it in the following steps?", blkno)) {
+			ret = 0;
+		}
+		goto out;
+	} else if (ret) {
 		com_err(whoami, ret, "while reading group descriptor "
 			"at block %"PRIu64" to fix cl_cpg", blkno);
 		goto out;
@@ -652,7 +660,7 @@ static errcode_t maybe_fix_clusters_per_group(o2fsck_state *ost,
 		cl->cl_cpg = new_cl_cpg;
 		ret = ocfs2_write_inode(ost->ost_fs, di->i_blkno, (char *)di);
 		if (ret) {
-			com_err(whoami, ret, "while writing inode alloc inode "
+			com_err(whoami, ret, "while writing global bitmap inode "
 				"%"PRIu64" to fix cl_cpg",
 				(uint64_t)di->i_blkno);
 			ost->ost_saw_error = 1;
@@ -1019,7 +1027,7 @@ static errcode_t verify_chain_alloc(o2fsck_state *ost,
 			   (uint64_t)di->i_blkno)) {
 
 			if (!trust_next_free) {
-				printf("Can't remove the chain becuase "
+				printf("Can't remove the chain because "
 				       "next_free_rec hasn't been fixed\n");
 				continue;
 			}
@@ -1219,8 +1227,8 @@ static errcode_t verify_bitmap_descs(o2fsck_state *ost,
 		 * its values.. we only preserve the bitmap if the signature
 		 * and generation match this volume */
 		ret = ocfs2_read_group_desc(ost->ost_fs, blkno, (char *)bg);
-		if (ret == OCFS2_ET_BAD_GROUP_DESC_MAGIC ||
-		    bg->bg_generation != ost->ost_fs_generation) {
+		if ((ret == OCFS2_ET_BAD_GROUP_DESC_MAGIC) ||
+		    (!ret && bg->bg_generation != ost->ost_fs_generation)) {
 			memset(bg, 0, ost->ost_fs->fs_blocksize);
 			ocfs2_init_group_desc(ost->ost_fs, bg, blkno,
 					      ost->ost_fs_generation,
@@ -1283,7 +1291,7 @@ static errcode_t verify_bitmap_descs(o2fsck_state *ost,
 
 		ret = ocfs2_write_inode(ost->ost_fs, di->i_blkno, (char *)di);
 		if (ret) {
-			com_err(whoami, ret, "while writing inode alloc inode "
+			com_err(whoami, ret, "while writing global bitmap inode "
 				    "%"PRIu64, (uint64_t)di->i_blkno);
 			ost->ost_saw_error = 1;
 			goto out;
@@ -1352,12 +1360,12 @@ errcode_t o2fsck_pass0(o2fsck_state *ost)
 
 	ret = ocfs2_read_inode(ost->ost_fs, blkno, (char *)di);
 	if (ret) {
-		com_err(whoami, ret, "reading inode alloc inode "
+		com_err(whoami, ret, "reading global bitmap inode "
 			"%"PRIu64" for verification", blkno);
 		goto out;
 	}
 
-	verbosef("found inode alloc %"PRIu64" at block %"PRIu64"\n",
+	verbosef("found global bitmap %"PRIu64" at block %"PRIu64"\n",
 		 (uint64_t)di->i_blkno, blkno);
 
 	ret = maybe_fix_clusters_per_group(ost, di);
@@ -1526,7 +1534,7 @@ retry_bitmap:
 
 		ret = ocfs2_read_inode(ost->ost_fs, blkno, (char *)di);
 		if (ret) {
-			com_err(whoami, ret, "reading inode alloc inode "
+			com_err(whoami, ret, "reading extent alloc inode "
 				"%"PRIu64" for verification", blkno);
 			goto out;
 		}
